configlet create


Ao adicionar uma nova abordagem, um novo artigo ou um novo exercício, você vai precisar criar arquivos com nomes bem específicos. Eles também exigem que arquivos de configuração sejam adicionados ou atualizados. Com o comando create, o configlet pode fazer tudo isso para você.

Uso

O comando create pode ser usado para criar os arquivos necessários para adicionar uma nova abordagem, um novo artigo ou um novo exercício, além de modificar quaisquer arquivos de configuração.

configlet [global-options] create [command-options]

Options for create:
      --approach <slug>           The slug of the approach
      --article <slug>            The slug of the article
      --practice-exercise <slug>  The slug of the practice exercise
      --concept-exercise <slug>   The slug of the concept exercise
  -e, --exercise <slug>           Only operate on this exercise
  -o, --offline                   Do not update the cached 'problem-specifications' data

Criar um exercício de prática

A documentação de como adicionar um exercício de prática tem instruções detalhadas sobre como adicionar um exercício de prática.

Criar um exercício de conceito

Para criar um exercício de conceito, é preciso especificar o slug dele:

configlet create --concept-exercise bird-watcher

Isso vai criar os arquivos necessários do exercício de conceito, conforme especificado na documentação de exercícios de conceito.

Claro, esse é só o primeiro passo para criar um exercício. Depois disso, você vai precisar:

  • Adicionar testes ao arquivo de testes
  • Adicionar uma implementação exemplar
  • Definir o conteúdo do arquivo stub
  • Escrever a introdução em .docs/introduction.md
  • Escrever as instruções em .docs/instructions.md
  • No arquivo .meta/config.json do exercício:
    • Adicionar o nome de usuário do GitHub dos autores do exercício à chave authors
  • No arquivo config.json da trilha:
    • Verificar/atualizar a dificuldade do exercício
    • Adicionar conceitos à chave concepts
    • Adicionar conceitos à chave prerequisites

Criar uma abordagem

Para criar os arquivos de uma abordagem, é preciso especificar o slug da abordagem e do exercício dela:

configlet create --approach recursion --exercise collatz-conjecture

Isso vai criar os arquivos necessários da abordagem, conforme especificado na documentação de abordagens.

Criar um artigo

Para criar os arquivos de um artigo, é preciso especificar o slug do artigo e do exercício dele:

configlet create --article performance --exercise collatz-conjecture

Isso vai criar os arquivos necessários do artigo, conforme especificado na documentação de artigos.